@@ -27,8 +27,20 @@ enum
   GPE_BUTTON_TYPE_BOTH
 };
 
-extern GtkWidget *gpe_picture_button (GtkStyle *style, 
-				      gchar *text, gchar *icon);
+typedef enum {
+  GPE_POS_LEFT,
+  GPE_POS_CENTER,
+  GPE_POS_RIGHT,
+  GPE_POS_TOP,
+  GPE_POS_BOTTOM
+} GpePositionType; //GtkPositionType does not provide _POS_CENTER
+
+extern GtkWidget * gpe_picture_button_aligned (GtkStyle *style,
+                                               gchar *text,
+                                               gchar *icon,
+                                               GpePositionType pos);
+
+extern GtkWidget *gpe_picture_button(GtkStyle *style, gchar *text, gchar *icon);
 extern GtkWidget *gpe_button_new_from_stock (const gchar *stock_id, int type);
 
 #endif
