@@ -24,6 +24,14 @@
 #include <gdk/gdk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
+#if GTK_MAJOR_VERSION < 2
+#error Compiling with GTK 1 is not supported
+#endif
+
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 struct gpe_icon
 {
   const char *shortname;
@@ -33,6 +41,7 @@ struct gpe_icon
 
 extern gboolean gpe_load_icons (struct gpe_icon *);
 extern GdkPixbuf *gpe_find_icon (const char *name);
+extern GdkPixbuf *gpe_find_icon_scaled (const char *name, GtkIconSize size);
 extern GdkPixbuf *gpe_try_find_icon (const char *name, gchar **error);
 extern gboolean gpe_find_icon_pixmap (const char *name,
 				      GdkPixmap **pixmap,
@@ -40,4 +49,8 @@ extern gboolean gpe_find_icon_pixmap (const char *name,
 
 extern void gpe_set_window_icon (GtkWidget *window, gchar *icon);
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 #endif
