@@ -26,7 +26,6 @@
 
 #include "errorbox.h"
 #include "what.h"
-#include "tap.h"
 #include "stylus.h"
 
 gint saved_argc;
@@ -87,9 +86,6 @@ gpe_application_init (int *argc, char **argv[])
 
   gpe_what_init ();
 
-  if (gpe_stylus_mode ())
-    tap_hold_init ();
-
   return TRUE;
 }
 
