@@ -27,50 +27,29 @@
 
 #include "init.h"
 
-#define SYSTEM_TRAY_OPCODE_ATOM	0
-#define MANAGER_ATOM		1
-static Atom atoms[2];
+#define SYSTEM_TRAY_OPCODE_ATOM	 0
+#define MANAGER_ATOM		 1
+#define SYSTEM_TRAY_MESSAGE_DATA 2
+
+static Atom atoms[3];
 
 static char *atom_names[] = 
   { 
     "_NET_SYSTEM_TRAY_OPCODE", 
-    "MANAGER" 
+    "MANAGER",
+    "_NET_SYSTEM_TRAY_MESSAGE_DATA"
   };
 
 static Atom system_tray_atom;
 
 static Window dock;
 
+#define MAX_DATA_BYTES 20
+
 #define SYSTEM_TRAY_REQUEST_DOCK    0
 #define SYSTEM_TRAY_BEGIN_MESSAGE   1
 #define SYSTEM_TRAY_CANCEL_MESSAGE  2
 
-static int (*old_error_handler) (Display *d, XErrorEvent *e);
-
-static int trapped_error_code;
-
-static int
-error_handler (Display     *display,
-	       XErrorEvent *error)
-{
-   trapped_error_code = error->error_code;
-   return 0;
-}
-
-static void
-trap_errors (void)
-{
-   trapped_error_code = 0;
-   old_error_handler = XSetErrorHandler (error_handler);
-}
-
-static int
-untrap_errors (void)
-{
-   XSetErrorHandler (old_error_handler);
-   return trapped_error_code;
-}
-
 static void
 tray_send_opcode (Display *dpy, Window w,
 		  long message, long data1, long data2, long data3)
@@ -89,10 +68,12 @@ tray_send_opcode (Display *dpy, Window w,
    ev.xclient.data.l[3] = data2;
    ev.xclient.data.l[4] = data3;
    
-   trap_errors ();
-   XSendEvent (dpy, w, False, NoEventMask, &ev);
-   XSync (dpy, False);
-   untrap_errors ();
+   gdk_error_trap_push ();
+
+   XSendEvent (dpy, dock, False, NoEventMask, &ev);
+
+   gdk_flush ();
+   gdk_error_trap_pop ();
 }
 
 static void
@@ -128,6 +109,68 @@ filter (GdkXEvent *xevp, GdkEvent *ev, gpointer p)
   return GDK_FILTER_CONTINUE;
 }
 
+guint
+gpe_system_tray_send_message (GdkWindow *window, const gchar *text, unsigned int timeout)
+{
+  static int id;
+  size_t len, bytes_sent;
+  XEvent ev;
+  char *buf;
+  Display *dpy;
+  Window win;
+
+  if (dock == None)
+    return -1;		/* not docked */
+
+  dpy = GDK_WINDOW_XDISPLAY (window);
+  win = GDK_WINDOW_XWINDOW (window);
+
+  ++id;
+
+  len = strlen (text);
+
+  tray_send_opcode (dpy, win, SYSTEM_TRAY_BEGIN_MESSAGE, timeout, len, id);
+
+  memset (&ev, 0, sizeof (ev));
+
+  ev.xclient.type = ClientMessage;
+  ev.xclient.window = win;
+  ev.xclient.message_type = atoms[SYSTEM_TRAY_MESSAGE_DATA];
+  ev.xclient.format = 8;
+
+  buf = &ev.xclient.data.b[0];
+
+  gdk_error_trap_push ();
+
+  for (bytes_sent = 0; bytes_sent < len; )
+    {
+      size_t s;
+
+      s = len - bytes_sent;
+
+      if (s > MAX_DATA_BYTES)
+	s = MAX_DATA_BYTES;
+      
+      memcpy (buf, text + bytes_sent, s);
+
+      XSendEvent (dpy, dock, False, NoEventMask, &ev);
+
+      bytes_sent += s;
+    }
+
+  gdk_flush ();
+  gdk_error_trap_pop ();
+
+  return id;
+}
+
+void
+gpe_system_tray_cancel_message (GdkWindow *window, guint id)
+{
+  tray_send_opcode (GDK_WINDOW_XDISPLAY (window), GDK_WINDOW_XWINDOW (window),
+		    SYSTEM_TRAY_CANCEL_MESSAGE, id, 0, 0);
+}
+
 void
 gpe_system_tray_dock (GdkWindow *window)
 {
@@ -137,7 +180,7 @@ gpe_system_tray_dock (GdkWindow *window)
   gint argc;
   gchar **argv;
 
-  XInternAtoms (dpy, atom_names, 2, False, atoms);
+  XInternAtoms (dpy, atom_names, 3, False, atoms);
   tray_atom_name = g_strdup_printf ("_NET_SYSTEM_TRAY_S%d", DefaultScreen (dpy));
   system_tray_atom = XInternAtom (dpy, tray_atom_name, False);
   g_free (tray_atom_name);
